#!/usr/bin/env NODE_OPTIONS=--no-warnings node

import 'zx/globals'
import { program } from 'commander'

import packageJson from './package.json' assert { type: 'json' }
import { heading } from './page.mjs'
import setup from './setup.mjs'
import apps from './apps.mjs'
import env, { envPush } from './env.mjs'

$.verbose = false
process.env.ENV = process.env.ENV ?? 'local'

program
  .name('dispense')
  .version(packageJson.version)
  .option('--debug', 'mocks installations for testing purposes')
  .option('--filter <app>', 'restrict commands to specific applications')

program.command('setup').description('install, login, and configure').action(setup)
program.command('apps').description('get info about monorepo apps').action(apps)

program
  .command('env')
  .description('[EXPERIMENTAL] manage environment variables')
  .option('--env <dev | staging | prod>', 'environment keys to push')
  .action(env)
  .command('push')
  .description('push variables from 1password to deploy targets')
  .action(envPush)

program
  .command('open')
  .description('open the monorepo in vscode')
  .option('--web', 'open the web view')
  .action(async () => {
    if (argv.web) {
      if (!(await $`gh auth status`)) await $`gh auth login`
      await $`gh repo view dispenseapp/dispense --web`
    } else $`code $DISPENSE_MONOREPO_PATH`
  })

program.addHelpText('beforeAll', heading)
program.parse()
